@@ -36,6 +36,10 @@ class LocalFileSystem(AbstractFileSystem):
         super().__init__(**kwargs)
         self.auto_mkdir = auto_mkdir
 
+    @property
+    def fsid(self):
+        return "local"
+
     def mkdir(self, path, create_parents=True, **kwargs):
         path = self._strip_protocol(path)
         if self.exists(path):
@@ -97,7 +101,7 @@ class LocalFileSystem(AbstractFileSystem):
             "created": out.st_ctime,
             "islink": link,
         }
-        for field in ["mode", "uid", "gid", "mtime"]:
+        for field in ["mode", "uid", "gid", "mtime", "ino", "nlink"]:
             result[field] = getattr(out, "st_" + field)
         if result["islink"]:
             result["destination"] = os.readlink(path)
@@ -138,11 +142,24 @@ class LocalFileSystem(AbstractFileSystem):
         path2 = self._strip_protocol(path2).rstrip("/")
         shutil.move(path1, path2)
 
+    def link(self, src, dst, **kwargs):
+        src = self._strip_protocol(src)
+        dst = self._strip_protocol(dst)
+        os.link(src, dst, **kwargs)
+
+    def symlink(self, src, dst, **kwargs):
+        src = self._strip_protocol(src)
+        dst = self._strip_protocol(dst)
+        os.symlink(src, dst, **kwargs)
+
+    def islink(self, path) -> bool:
+        return os.path.islink(self._strip_protocol(path))
+
     def rm_file(self, path):
         os.remove(path)
 
     def rm(self, path, recursive=False, maxdepth=None):
-        if isinstance(path, str):
+        if not isinstance(path, list):
             path = [path]
 
         for p in path:
@@ -155,6 +172,10 @@ class LocalFileSystem(AbstractFileSystem):
             else:
                 os.remove(p)
 
+    def unstrip_protocol(self, name):
+        name = self._strip_protocol(name)  # normalise for local/win/...
+        return f"file://{name}"
+
     def _open(self, path, mode="rb", block_size=None, **kwargs):
         path = self._strip_protocol(path)
         if self.auto_mkdir and "w" in mode:
@@ -193,6 +214,8 @@ class LocalFileSystem(AbstractFileSystem):
         path = stringify_path(path)
         if path.startswith("file://"):
             path = path[7:]
+        elif path.startswith("file:"):
+            path = path[5:]
         return make_path_posix(path).rstrip("/") or cls.root_marker
 
     def _isfilestore(self):
@@ -216,6 +239,8 @@ def make_path_posix(path, sep=os.sep):
         # most common fast case for posix
         if path.startswith("/"):
             return path
+        if path.startswith("./"):
+            path = path[2:]
         return os.getcwd() + "/" + path
     if (
         (sep not in path and "/" not in path)
@@ -228,10 +253,12 @@ def make_path_posix(path, sep=os.sep):
             return make_path_posix(osp.abspath(path))
         else:
             return os.getcwd() + "/" + path
+    if path.startswith("file://"):
+        path = path[7:]
     if re.match("/[A-Za-z]:", path):
         # for windows file URI like "file:///C:/folder/file"
         # or "file:///C:\\dir\\file"
-        path = path[1:]
+        path = path[1:].replace("\\", "/").replace("//", "/")
     if path.startswith("\\\\"):
         # special case for windows UNC/DFS-style paths, do nothing,
         # just flip the slashes around (case below does not work!)
@@ -245,6 +272,33 @@ def make_path_posix(path, sep=os.sep):
     return path
 
 
+def trailing_sep(path):
+    """Return True if the path ends with a path separator.
+
+    A forward slash is always considered a path separator, even on Operating
+    Systems that normally use a backslash.
+    """
+    # TODO: if all incoming paths were posix-compliant then separator would
+    # always be a forward slash, simplifying this function.
+    # See https://github.com/fsspec/filesystem_spec/pull/1250
+    return path.endswith(os.sep) or (os.altsep is not None and path.endswith(os.altsep))
+
+
+def trailing_sep_maybe_asterisk(path):
+    """Return True if the path ends with a path separator and optionally an
+    asterisk.
+
+    A forward slash is always considered a path separator, even on Operating
+    Systems that normally use a backslash.
+    """
+    # TODO: if all incoming paths were posix-compliant then separator would
+    # always be a forward slash, simplifying this function.
+    # See https://github.com/fsspec/filesystem_spec/pull/1250
+    return path.endswith((os.sep, os.sep + "*")) or (
+        os.altsep is not None and path.endswith((os.altsep, os.altsep + "*"))
+    )
+
+
 class LocalFileOpener(io.IOBase):
     def __init__(
         self, path, mode, autocommit=True, fs=None, compression=None, **kwargs
@@ -351,6 +405,9 @@ class LocalFileOpener(io.IOBase):
     def fileno(self):
         return self.raw.fileno()
 
+    def flush(self) -> None:
+        self.f.flush()
+
     def __iter__(self):
         return self.f.__iter__()
 
